import { App as Application } from 'vue';
import QCalendar from './components/QCalendar';
import QCalendarAgenda from './components/QCalendarAgenda';
import QCalendarDay from './components/QCalendarDay';
import QCalendarMonth from './components/QCalendarMonth';
import QCalendarResource from './components/QCalendarResource';
import QCalendarScheduler from './components/QCalendarScheduler';
import QCalendarTask from './components/QCalendarTask';
import { version } from './version.js';
import * as Timestamp from './utils/Timestamp';
import * as helpers from './utils/helpers';
export * from './utils/Timestamp';
export * from './utils/helpers';
export { version, QCalendar, QCalendarAgenda, QCalendarDay, QCalendarMonth, QCalendarResource, QCalendarScheduler, QCalendarTask, };
declare const _default: {
    install(app: Application): void;
    convertToUnit(input: any, unit?: string): string | undefined;
    indexOf(array: any[], cb: (_element: any, _index: number) => boolean): number;
    minCharWidth(str: string, count: number): string;
    default: {
        convertToUnit: typeof helpers.convertToUnit;
        indexOf: typeof helpers.indexOf;
        minCharWidth: typeof helpers.minCharWidth;
    };
    validateTimestamp(input: string): boolean;
    parsed(input: string): Timestamp.Timestamp | null;
    parseDate(date: Date, utc?: boolean): Timestamp.Timestamp | null;
    padNumber(x: number, length: number): string;
    isLeapYear(year: number): boolean;
    daysInMonth(year: number, month: number): number;
    nextDay(timestamp: Timestamp.Timestamp): Timestamp.Timestamp;
    prevDay(timestamp: Timestamp.Timestamp): Timestamp.Timestamp;
    today(): string;
    isToday(date: string): boolean;
    getStartOfWeek(timestamp: Timestamp.Timestamp, weekdays: number[], today: Timestamp.Timestamp): Timestamp.Timestamp;
    getEndOfWeek(timestamp: Timestamp.Timestamp, weekdays: number[], today: Timestamp.Timestamp): Timestamp.Timestamp;
    getStartOfMonth(timestamp: Timestamp.Timestamp): Timestamp.Timestamp;
    getEndOfMonth(timestamp: Timestamp.Timestamp): Timestamp.Timestamp;
    parseTime(input: number | string | {
        hour: number;
        minute: number;
    }): number | false;
    compareTimestamps(ts1: Timestamp.Timestamp, ts2: Timestamp.Timestamp): boolean;
    compareDate(ts1: Timestamp.Timestamp, ts2: Timestamp.Timestamp): boolean;
    compareTime(ts1: Timestamp.Timestamp, ts2: Timestamp.Timestamp): boolean;
    compareDateTime(ts1: Timestamp.Timestamp, ts2: Timestamp.Timestamp): boolean;
    parseTimestamp(input: string, now?: Timestamp.Timestamp | null): Timestamp.Timestamp | null;
    getDayIdentifier(timestamp: Timestamp.Timestamp): number;
    getTimeIdentifier(timestamp: Timestamp.Timestamp): number;
    getDayTimeIdentifier(timestamp: Timestamp.Timestamp): number;
    diffTimestamp(ts1: Timestamp.Timestamp, ts2: Timestamp.Timestamp, strict?: boolean): number;
    updateRelative(timestamp: Timestamp.Timestamp, now: Timestamp.Timestamp, time?: boolean): Timestamp.Timestamp;
    updateMinutes(timestamp: Timestamp.Timestamp, minutes: number, now?: Timestamp.Timestamp | null): Timestamp.Timestamp;
    updateWeekday(timestamp: Timestamp.Timestamp): Timestamp.Timestamp;
    updateDayOfYear(timestamp: Timestamp.Timestamp): Timestamp.Timestamp;
    updateWorkWeek(timestamp: Timestamp.Timestamp): Timestamp.Timestamp;
    updateDisabled(timestamp: Timestamp.Timestamp, disabledBefore?: string, disabledAfter?: string, disabledWeekdays?: number[], disabledDays?: string[] | string[][]): Timestamp.Timestamp;
    updateFormatted(timestamp: Timestamp.Timestamp): Timestamp.Timestamp;
    getDayOfYear(timestamp: Timestamp.Timestamp): number | void;
    getWorkWeek(timestamp: Timestamp.Timestamp): number;
    getWeekday(timestamp: Timestamp.Timestamp): number;
    copyTimestamp(timestamp: Timestamp.Timestamp): Timestamp.Timestamp;
    getDate(timestamp: Timestamp.Timestamp): string;
    getTime(timestamp: Timestamp.Timestamp): string;
    getDateTime(timestamp: Timestamp.Timestamp): string;
    moveRelativeDays(timestamp: Timestamp.Timestamp, mover?: typeof Timestamp.nextDay, days?: number, allowedWeekdays?: number[]): Timestamp.Timestamp;
    relativeDays(timestamp: Timestamp.Timestamp, mover?: typeof Timestamp.nextDay, days?: number, allowedWeekdays?: number[]): Timestamp.Timestamp;
    findWeekday(timestamp: Timestamp.Timestamp, weekday: number, mover?: typeof Timestamp.nextDay, maxDays?: number): Timestamp.Timestamp;
    createDayList(start: Timestamp.Timestamp, end: Timestamp.Timestamp, now: Timestamp.Timestamp, weekdays?: number[], disabledBefore?: string | undefined, disabledAfter?: string | undefined, disabledWeekdays?: number[], disabledDays?: string[], max?: number, min?: number): Timestamp.Timestamp[];
    createIntervalList(timestamp: Timestamp.Timestamp, first: number, minutes: number, count: number, now: Timestamp.Timestamp): Timestamp.Timestamp[];
    createNativeLocaleFormatter(locale: string, cb: Timestamp.LocaleFormatter): (_timestamp: Timestamp.Timestamp, _short: boolean) => string;
    makeDate(timestamp: Timestamp.Timestamp, utc?: boolean): Date;
    makeDateTime(timestamp: Timestamp.Timestamp, utc?: boolean): Date;
    validateNumber(input: string | number): boolean;
    maxTimestamp(timestamps: Timestamp.Timestamp[], useTime?: boolean): Timestamp.Timestamp;
    minTimestamp(timestamps: Timestamp.Timestamp[], useTime?: boolean): Timestamp.Timestamp;
    isBetweenDates(timestamp: Timestamp.Timestamp, startTimestamp: Timestamp.Timestamp, endTimestamp: Timestamp.Timestamp, useTime?: boolean): boolean;
    isOverlappingDates(startTimestamp: Timestamp.Timestamp, endTimestamp: Timestamp.Timestamp, firstTimestamp: Timestamp.Timestamp, lastTimestamp: Timestamp.Timestamp): boolean;
    addToDate(timestamp: Timestamp.Timestamp, options: Timestamp.AddToDateOptions): Timestamp.Timestamp;
    daysBetween(ts1: Timestamp.Timestamp, ts2: Timestamp.Timestamp): number;
    weeksBetween(ts1: Timestamp.Timestamp, ts2: Timestamp.Timestamp): number;
    getWeekdayFormatter(): Timestamp.WeekdayFormatter;
    getWeekdayNames(type: string, locale: string): string[];
    getMonthFormatter(): Timestamp.MonthFormatter;
    getMonthNames(type: string, locale: string): string[];
    PARSE_DATETIME: RegExp;
    PARSE_DATE: RegExp;
    PARSE_TIME: RegExp;
    DAYS_IN_MONTH: number[];
    DAYS_IN_MONTH_LEAP: number[];
    TIME_CONSTANTS: {
        MILLISECONDS_IN: {
            SECOND: number;
            MINUTE: number;
            HOUR: number;
            DAY: number;
            WEEK: number;
        };
        SECONDS_IN: {
            MINUTE: number;
            HOUR: number;
            DAY: number;
            WEEK: number;
        };
        MINUTES_IN: {
            MINUTE: number;
            HOUR: number;
            DAY: number;
            WEEK: number;
        };
        HOURS_IN: {
            DAY: number;
            WEEK: number;
        };
        DAYS_IN: {
            WEEK: number;
        };
    };
    DAYS_IN_MONTH_MIN: 28;
    DAYS_IN_MONTH_MAX: 31;
    MONTH_MAX: 12;
    MONTH_MIN: 1;
    DAY_MIN: 1;
    FIRST_HOUR: 0;
    version: string;
    QCalendar: import("vue").DefineComponent<{
        mode: string;
        modelValue: string;
        weekdays: number[];
        dateType: string;
        weekdayAlign: string;
        dateAlign: string;
        bordered: boolean;
        dark: boolean;
        noAria: boolean;
        noActiveDate: boolean;
        noHeader: boolean;
        noScroll: boolean;
        shortWeekdayLabel: boolean;
        noDefaultHeaderText: boolean;
        noDefaultHeaderBtn: boolean;
        minWeekdayLabel: number | string;
        weekdayBreakpoints: number[];
        locale: string;
        animated: boolean;
        transitionNext: string;
        transitionPrev: string;
    }, () => import("vue").VNode, {}, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<{
        mode: string;
        modelValue: string;
        weekdays: number[];
        dateType: string;
        weekdayAlign: string;
        dateAlign: string;
        bordered: boolean;
        dark: boolean;
        noAria: boolean;
        noActiveDate: boolean;
        noHeader: boolean;
        noScroll: boolean;
        shortWeekdayLabel: boolean;
        noDefaultHeaderText: boolean;
        noDefaultHeaderBtn: boolean;
        minWeekdayLabel: number | string;
        weekdayBreakpoints: number[];
        locale: string;
        animated: boolean;
        transitionNext: string;
        transitionPrev: string;
    }> & Readonly<{}>, {
        mode: string;
        dark: boolean;
        focusable: boolean;
        now: string;
        maxDays: number;
        shortIntervalLabel: boolean;
        intervalHeight: string | number;
        intervalMinutes: string | number;
        intervalStart: string | number;
        intervalCount: string | number;
        intervalStyle: ((_scope: import("./composables/useInterval").Scope) => any) | undefined;
        intervalClass: ((_scope: import("./composables/useInterval").Scope) => string) | undefined;
        weekdayStyle: Function;
        weekdayClass: Function;
        showIntervalLabel: ((_timestamp: Timestamp.Timestamp) => any) | undefined;
        hour24Format: boolean;
        timeClicksClamped: boolean;
        dateHeader: "inline" | "stacked" | "inverted";
        modelValue: string;
        weekdays: number[];
        dateType: "square" | "round" | "rounded";
        weekdayAlign: "center" | "left" | "right";
        dateAlign: "center" | "left" | "right";
        bordered: boolean;
        noAria: boolean;
        noActiveDate: boolean;
        noHeader: boolean;
        noScroll: boolean;
        shortWeekdayLabel: boolean;
        noDefaultHeaderText: boolean;
        noDefaultHeaderBtn: boolean;
        minWeekdayLabel: string | number;
        weekdayBreakpoints: number[];
        locale: string;
        animated: boolean;
        transitionPrev: string;
        transitionNext: string;
        disabledWeekdays: number[];
        selectedDates: string[] | Set<string>;
        selectedStartEndDates: string[];
        hoverable: boolean;
        focusType: ("time" | "interval" | "day" | "weekday" | "date" | "resource" | "task")[];
        resourceKey: string;
        resourceLabel: string;
        resourceHeight: string | number;
        resourceMinHeight: string | number;
        resourceStyle: ((_scope: any) => any) | undefined;
        resourceClass: ((_scope: any) => string) | undefined;
        dayStyle: Function;
        dayClass: Function;
        dayHeight: string | number;
        dayMinHeight: string | number;
        cellWidth: string | number;
        intervalHeaderHeight: string | number;
        useNavigation: boolean;
        minWeeks: string | number;
        shortMonthLabel: boolean;
        showWorkWeeks: boolean;
        showMonthLabel: boolean;
        showDayOfYearLabel: boolean;
        enableOutsideDays: boolean;
        noOutsideDays: boolean;
        hover: boolean;
        breakpoint: string | number;
        monthLabelSize: string;
        modelTasks: any[];
        modelTitle: any[];
        modelFooter: any[];
        taskKey: string | number;
        footerDayClass: Function;
        viewCount: number;
        taskWidth: number;
    }, {}, {}, {}, string, import("vue").ComponentProvideOptions, true, {}, any>;
    QCalendarAgenda: import("vue").DefineComponent<{
        view: "day" | "week" | "month" | "month-interval";
        leftColumnOptions?: any[] | undefined;
        rightColumnOptions?: any[] | undefined;
        columnOptionsId?: string | undefined;
        columnOptionsLabel?: string | undefined;
        dayStyle?: (((_scope: import("./composables/useInterval").Scope) => any) & ((_scope: import("./composables/useInterval").Scope) => any)) | undefined;
        dayClass?: (((_scope: import("./composables/useInterval").Scope) => string) & ((_scope: import("./composables/useInterval").Scope) => string)) | undefined;
        dayHeight: number | string;
        dayMinHeight: number | string;
        shortIntervalLabel?: boolean | undefined;
        intervalHeight: number | string;
        intervalMinutes: number | string;
        intervalStart: number | string;
        intervalCount: number | string;
        intervalStyle?: ((_scope: import("./composables/useInterval").Scope) => any) | undefined;
        intervalClass?: ((_scope: import("./composables/useInterval").Scope) => string) | undefined;
        weekdayStyle?: (((_scope: import("./composables/useInterval").Scope) => any) & ((_scope: import("./composables/useInterval").Scope) => any)) | undefined;
        weekdayClass?: (((_scope: import("./composables/useInterval").Scope) => string) & ((_scope: import("./composables/useInterval").Scope) => string)) | undefined;
        showIntervalLabel?: ((_timestamp: Timestamp.Timestamp) => any) | undefined;
        hour24Format?: boolean | undefined;
        timeClicksClamped?: boolean | undefined;
        dateHeader: "stacked" | "inline" | "inverted";
        modelValue: string;
        weekdays: number[];
        dateType: "round" | "rounded" | "square";
        weekdayAlign: "left" | "center" | "right";
        dateAlign: "left" | "center" | "right";
        bordered: boolean;
        dark: boolean;
        noAria: boolean;
        noActiveDate: boolean;
        noHeader: boolean;
        noScroll: boolean;
        shortWeekdayLabel: boolean;
        noDefaultHeaderText: boolean;
        noDefaultHeaderBtn: boolean;
        minWeekdayLabel: number | string;
        weekdayBreakpoints: number[];
        locale: string;
        animated: boolean;
        transitionPrev: string;
        transitionNext: string;
        disabledDays?: string[] | undefined;
        disabledBefore?: string | undefined;
        disabledAfter?: string | undefined;
        disabledWeekdays?: number[] | undefined;
        dragEnterFunc?: ((_event: Event, _type: string, _scope: any) => boolean) | undefined;
        dragOverFunc?: ((_event: Event, _type: string, _scope: any) => boolean) | undefined;
        dragLeaveFunc?: ((_event: Event, _type: string, _scope: any) => boolean) | undefined;
        dropFunc?: ((_event: Event, _type: string, _scope: any) => boolean) | undefined;
        selectedDates: string[] | Set<string>;
        selectedStartEndDates: string[];
        hoverable: boolean;
        focusable: boolean;
        focusType: ("day" | "date" | "weekday" | "interval" | "time" | "resource" | "task")[];
        columnCount: number | string;
        columnIndexStart: number | string;
        cellWidth: number | string;
        maxDays: number;
        now: string;
        useNavigation: boolean;
        modelResources?: import("./composables/useInterval").Resource[] | undefined;
        resourceKey: string;
        resourceLabel: string;
        resourceHeight: number | string;
        resourceMinHeight: number | string;
        resourceStyle?: (((_timestamp: Timestamp.Timestamp) => any) & ((_scope: any) => any)) | undefined;
        resourceClass?: (((_scope: import("./composables/useInterval").Scope) => string) & ((_scope: any) => string)) | undefined;
        intervalHeaderHeight: number | string;
        noSticky?: boolean | undefined;
    }, () => import("vue").VNode, {}, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<{
        view: "day" | "week" | "month" | "month-interval";
        leftColumnOptions?: any[] | undefined;
        rightColumnOptions?: any[] | undefined;
        columnOptionsId?: string | undefined;
        columnOptionsLabel?: string | undefined;
        dayStyle?: (((_scope: import("./composables/useInterval").Scope) => any) & ((_scope: import("./composables/useInterval").Scope) => any)) | undefined;
        dayClass?: (((_scope: import("./composables/useInterval").Scope) => string) & ((_scope: import("./composables/useInterval").Scope) => string)) | undefined;
        dayHeight: number | string;
        dayMinHeight: number | string;
        shortIntervalLabel?: boolean | undefined;
        intervalHeight: number | string;
        intervalMinutes: number | string;
        intervalStart: number | string;
        intervalCount: number | string;
        intervalStyle?: ((_scope: import("./composables/useInterval").Scope) => any) | undefined;
        intervalClass?: ((_scope: import("./composables/useInterval").Scope) => string) | undefined;
        weekdayStyle?: (((_scope: import("./composables/useInterval").Scope) => any) & ((_scope: import("./composables/useInterval").Scope) => any)) | undefined;
        weekdayClass?: (((_scope: import("./composables/useInterval").Scope) => string) & ((_scope: import("./composables/useInterval").Scope) => string)) | undefined;
        showIntervalLabel?: ((_timestamp: Timestamp.Timestamp) => any) | undefined;
        hour24Format?: boolean | undefined;
        timeClicksClamped?: boolean | undefined;
        dateHeader: "stacked" | "inline" | "inverted";
        modelValue: string;
        weekdays: number[];
        dateType: "round" | "rounded" | "square";
        weekdayAlign: "left" | "center" | "right";
        dateAlign: "left" | "center" | "right";
        bordered: boolean;
        dark: boolean;
        noAria: boolean;
        noActiveDate: boolean;
        noHeader: boolean;
        noScroll: boolean;
        shortWeekdayLabel: boolean;
        noDefaultHeaderText: boolean;
        noDefaultHeaderBtn: boolean;
        minWeekdayLabel: number | string;
        weekdayBreakpoints: number[];
        locale: string;
        animated: boolean;
        transitionPrev: string;
        transitionNext: string;
        disabledDays?: string[] | undefined;
        disabledBefore?: string | undefined;
        disabledAfter?: string | undefined;
        disabledWeekdays?: number[] | undefined;
        dragEnterFunc?: ((_event: Event, _type: string, _scope: any) => boolean) | undefined;
        dragOverFunc?: ((_event: Event, _type: string, _scope: any) => boolean) | undefined;
        dragLeaveFunc?: ((_event: Event, _type: string, _scope: any) => boolean) | undefined;
        dropFunc?: ((_event: Event, _type: string, _scope: any) => boolean) | undefined;
        selectedDates: string[] | Set<string>;
        selectedStartEndDates: string[];
        hoverable: boolean;
        focusable: boolean;
        focusType: ("day" | "date" | "weekday" | "interval" | "time" | "resource" | "task")[];
        columnCount: number | string;
        columnIndexStart: number | string;
        cellWidth: number | string;
        maxDays: number;
        now: string;
        useNavigation: boolean;
        modelResources?: import("./composables/useInterval").Resource[] | undefined;
        resourceKey: string;
        resourceLabel: string;
        resourceHeight: number | string;
        resourceMinHeight: number | string;
        resourceStyle?: (((_timestamp: Timestamp.Timestamp) => any) & ((_scope: any) => any)) | undefined;
        resourceClass?: (((_scope: import("./composables/useInterval").Scope) => string) & ((_scope: any) => string)) | undefined;
        intervalHeaderHeight: number | string;
        noSticky?: boolean | undefined;
    }> & Readonly<{}>, {
        view: "day" | "month" | "week" | "month-interval";
        columnCount: string | number;
        dark: boolean;
        focusable: boolean;
        columnIndexStart: string | number;
        now: string;
        maxDays: number;
        weekdayStyle: ((_scope: import("./composables/useInterval").Scope) => any) | undefined;
        weekdayClass: ((_scope: import("./composables/useInterval").Scope) => string) | undefined;
        dateHeader: "inline" | "stacked" | "inverted";
        modelValue: string;
        weekdays: number[];
        dateType: "square" | "round" | "rounded";
        weekdayAlign: "center" | "left" | "right";
        dateAlign: "center" | "left" | "right";
        bordered: boolean;
        noAria: boolean;
        noActiveDate: boolean;
        noHeader: boolean;
        noScroll: boolean;
        shortWeekdayLabel: boolean;
        noDefaultHeaderText: boolean;
        noDefaultHeaderBtn: boolean;
        minWeekdayLabel: string | number;
        weekdayBreakpoints: number[];
        locale: string;
        animated: boolean;
        transitionPrev: string;
        transitionNext: string;
        disabledWeekdays: number[];
        selectedDates: string[] | Set<string>;
        selectedStartEndDates: string[];
        hoverable: boolean;
        focusType: ("time" | "interval" | "day" | "weekday" | "date" | "resource" | "task")[];
        dayStyle: ((_scope: import("./composables/useInterval").Scope) => any) | undefined;
        dayClass: ((_scope: import("./composables/useInterval").Scope) => string) | undefined;
        dayHeight: string | number;
        dayMinHeight: string | number;
        useNavigation: boolean;
    }, {}, {}, {
        ResizeObserver: import("vue").Directive;
    }, string, import("vue").ComponentProvideOptions, true, {}, any>;
    QCalendarDay: import("vue").DefineComponent<{
        view: "day" | "week" | "month" | "month-interval";
        shortIntervalLabel?: boolean | undefined;
        intervalHeight: number | string;
        intervalMinutes: number | string;
        intervalStart: number | string;
        intervalCount: number | string;
        intervalStyle?: ((_scope: import("./composables/useInterval").Scope) => any) | undefined;
        intervalClass?: ((_scope: import("./composables/useInterval").Scope) => string) | undefined;
        weekdayStyle?: ((_scope: import("./composables/useInterval").Scope) => any) | undefined;
        weekdayClass?: ((_scope: import("./composables/useInterval").Scope) => string) | undefined;
        showIntervalLabel?: ((_timestamp: Timestamp.Timestamp) => any) | undefined;
        hour24Format?: boolean | undefined;
        timeClicksClamped?: boolean | undefined;
        dateHeader: "stacked" | "inline" | "inverted";
        modelValue: string;
        weekdays: number[];
        dateType: "round" | "rounded" | "square";
        weekdayAlign: "left" | "center" | "right";
        dateAlign: "left" | "center" | "right";
        bordered: boolean;
        dark: boolean;
        noAria: boolean;
        noActiveDate: boolean;
        noHeader: boolean;
        noScroll: boolean;
        shortWeekdayLabel: boolean;
        noDefaultHeaderText: boolean;
        noDefaultHeaderBtn: boolean;
        minWeekdayLabel: number | string;
        weekdayBreakpoints: number[];
        locale: string;
        animated: boolean;
        transitionPrev: string;
        transitionNext: string;
        disabledDays?: string[] | undefined;
        disabledBefore?: string | undefined;
        disabledAfter?: string | undefined;
        disabledWeekdays?: number[] | undefined;
        dragEnterFunc?: ((_event: Event, _type: string, _scope: any) => boolean) | undefined;
        dragOverFunc?: ((_event: Event, _type: string, _scope: any) => boolean) | undefined;
        dragLeaveFunc?: ((_event: Event, _type: string, _scope: any) => boolean) | undefined;
        dropFunc?: ((_event: Event, _type: string, _scope: any) => boolean) | undefined;
        selectedDates: string[] | Set<string>;
        selectedStartEndDates: string[];
        hoverable: boolean;
        focusable: boolean;
        focusType: ("day" | "date" | "weekday" | "interval" | "time" | "resource" | "task")[];
        columnCount: number | string;
        columnIndexStart: number | string;
        cellWidth?: number | string | undefined;
        maxDays: number;
        now: string;
        useNavigation: boolean;
    }, () => import("vue").VNode, {}, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<{
        view: "day" | "week" | "month" | "month-interval";
        shortIntervalLabel?: boolean | undefined;
        intervalHeight: number | string;
        intervalMinutes: number | string;
        intervalStart: number | string;
        intervalCount: number | string;
        intervalStyle?: ((_scope: import("./composables/useInterval").Scope) => any) | undefined;
        intervalClass?: ((_scope: import("./composables/useInterval").Scope) => string) | undefined;
        weekdayStyle?: ((_scope: import("./composables/useInterval").Scope) => any) | undefined;
        weekdayClass?: ((_scope: import("./composables/useInterval").Scope) => string) | undefined;
        showIntervalLabel?: ((_timestamp: Timestamp.Timestamp) => any) | undefined;
        hour24Format?: boolean | undefined;
        timeClicksClamped?: boolean | undefined;
        dateHeader: "stacked" | "inline" | "inverted";
        modelValue: string;
        weekdays: number[];
        dateType: "round" | "rounded" | "square";
        weekdayAlign: "left" | "center" | "right";
        dateAlign: "left" | "center" | "right";
        bordered: boolean;
        dark: boolean;
        noAria: boolean;
        noActiveDate: boolean;
        noHeader: boolean;
        noScroll: boolean;
        shortWeekdayLabel: boolean;
        noDefaultHeaderText: boolean;
        noDefaultHeaderBtn: boolean;
        minWeekdayLabel: number | string;
        weekdayBreakpoints: number[];
        locale: string;
        animated: boolean;
        transitionPrev: string;
        transitionNext: string;
        disabledDays?: string[] | undefined;
        disabledBefore?: string | undefined;
        disabledAfter?: string | undefined;
        disabledWeekdays?: number[] | undefined;
        dragEnterFunc?: ((_event: Event, _type: string, _scope: any) => boolean) | undefined;
        dragOverFunc?: ((_event: Event, _type: string, _scope: any) => boolean) | undefined;
        dragLeaveFunc?: ((_event: Event, _type: string, _scope: any) => boolean) | undefined;
        dropFunc?: ((_event: Event, _type: string, _scope: any) => boolean) | undefined;
        selectedDates: string[] | Set<string>;
        selectedStartEndDates: string[];
        hoverable: boolean;
        focusable: boolean;
        focusType: ("day" | "date" | "weekday" | "interval" | "time" | "resource" | "task")[];
        columnCount: number | string;
        columnIndexStart: number | string;
        cellWidth?: number | string | undefined;
        maxDays: number;
        now: string;
        useNavigation: boolean;
    }> & Readonly<{}>, {
        view: "day" | "month" | "week" | "month-interval";
        columnCount: string | number;
        dark: boolean;
        focusable: boolean;
        columnIndexStart: string | number;
        now: string;
        maxDays: number;
        shortIntervalLabel: boolean;
        intervalHeight: string | number;
        intervalMinutes: string | number;
        intervalStart: string | number;
        intervalCount: string | number;
        intervalStyle: ((_scope: import("./composables/useInterval").Scope) => any) | undefined;
        intervalClass: ((_scope: import("./composables/useInterval").Scope) => string) | undefined;
        weekdayStyle: ((_scope: import("./composables/useInterval").Scope) => any) | undefined;
        weekdayClass: ((_scope: import("./composables/useInterval").Scope) => string) | undefined;
        showIntervalLabel: ((_timestamp: Timestamp.Timestamp) => any) | undefined;
        hour24Format: boolean;
        timeClicksClamped: boolean;
        dateHeader: "inline" | "stacked" | "inverted";
        modelValue: string;
        weekdays: number[];
        dateType: "square" | "round" | "rounded";
        weekdayAlign: "center" | "left" | "right";
        dateAlign: "center" | "left" | "right";
        bordered: boolean;
        noAria: boolean;
        noActiveDate: boolean;
        noHeader: boolean;
        noScroll: boolean;
        shortWeekdayLabel: boolean;
        noDefaultHeaderText: boolean;
        noDefaultHeaderBtn: boolean;
        minWeekdayLabel: string | number;
        weekdayBreakpoints: number[];
        locale: string;
        animated: boolean;
        transitionPrev: string;
        transitionNext: string;
        disabledWeekdays: number[];
        selectedDates: string[] | Set<string>;
        selectedStartEndDates: string[];
        hoverable: boolean;
        focusType: ("time" | "interval" | "day" | "weekday" | "date" | "resource" | "task")[];
        useNavigation: boolean;
    }, {}, {}, {
        ResizeObserver: import("vue").Directive;
    }, string, import("vue").ComponentProvideOptions, true, {}, any>;
    QCalendarMonth: import("vue").DefineComponent<import("vue").ExtractPropTypes<{
        useNavigation: BooleanConstructor;
        cellWidth: (StringConstructor | NumberConstructor)[];
        now: {
            type: StringConstructor;
            validator: (v: string) => boolean;
            default: string;
        };
        dayHeight: {
            type: (StringConstructor | NumberConstructor)[];
            default: number;
            validator: (v: any) => boolean;
        };
        dayMinHeight: {
            type: (StringConstructor | NumberConstructor)[];
            default: number;
            validator: (v: any) => boolean;
        };
        dayStyle: FunctionConstructor;
        dayClass: FunctionConstructor;
        weekdayStyle: FunctionConstructor;
        weekdayClass: FunctionConstructor;
        dayPadding: StringConstructor;
        minWeeks: {
            type: (StringConstructor | NumberConstructor)[];
            default: number;
            validator: (v: any) => boolean;
        };
        shortMonthLabel: BooleanConstructor;
        showWorkWeeks: BooleanConstructor;
        showMonthLabel: {
            type: BooleanConstructor;
            default: boolean;
        };
        showDayOfYearLabel: BooleanConstructor;
        enableOutsideDays: BooleanConstructor;
        noOutsideDays: BooleanConstructor;
        hover: BooleanConstructor;
        miniMode: {
            type: (StringConstructor | BooleanConstructor)[];
            validator: (v: any) => boolean;
        };
        breakpoint: {
            type: (StringConstructor | NumberConstructor)[];
            default: string;
            validator: (v: any) => boolean;
        };
        monthLabelSize: {
            type: StringConstructor;
            default: string;
            validator: (v: any) => boolean;
        };
        modelValue: {
            type: StringConstructor;
            default: string;
            validator: (v: string) => boolean;
        };
        weekdays: {
            type: () => number[];
            default: () => number[];
        };
        dateType: {
            type: () => "round" | "rounded" | "square";
            default: string;
            validator: (v: string) => boolean;
        };
        weekdayAlign: {
            type: () => "left" | "center" | "right";
            default: string;
            validator: (v: string) => boolean;
        };
        dateAlign: {
            type: () => "left" | "center" | "right";
            default: string;
            validator: (v: string) => boolean;
        };
        bordered: BooleanConstructor;
        dark: BooleanConstructor;
        noAria: BooleanConstructor;
        noActiveDate: BooleanConstructor;
        noHeader: BooleanConstructor;
        noScroll: BooleanConstructor;
        shortWeekdayLabel: BooleanConstructor;
        noDefaultHeaderText: BooleanConstructor;
        noDefaultHeaderBtn: BooleanConstructor;
        minWeekdayLabel: {
            type: import("vue").PropType<number | string>;
            default: number;
        };
        weekdayBreakpoints: {
            type: () => number[];
            default: () => number[];
            validator: (v: number[]) => boolean;
        };
        locale: {
            type: StringConstructor;
            default: string;
        };
        animated: BooleanConstructor;
        transitionPrev: {
            type: StringConstructor;
            default: string;
        };
        transitionNext: {
            type: StringConstructor;
            default: string;
        };
        disabledDays: () => string[];
        disabledBefore: StringConstructor;
        disabledAfter: StringConstructor;
        disabledWeekdays: {
            type: () => number[];
            default: () => string[] | Set<string>;
        };
        dragEnterFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dragOverFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dragLeaveFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dropFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        selectedDates: {
            type: import("vue").PropType<string[] | Set<string>>;
            default: () => string[] | Set<string>;
        };
        selectedStartEndDates: {
            type: () => string[];
            default: () => string[];
        };
        hoverable: BooleanConstructor;
        focusable: BooleanConstructor;
        focusType: {
            type: () => ("day" | "date" | "weekday" | "interval" | "time" | "resource" | "task")[];
            default: () => ("day" | "date" | "weekday" | "interval" | "time" | "resource" | "task")[];
            validator: (v: string[]) => boolean;
        };
    }>, () => import("vue").VNode, {}, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
        useNavigation: BooleanConstructor;
        cellWidth: (StringConstructor | NumberConstructor)[];
        now: {
            type: StringConstructor;
            validator: (v: string) => boolean;
            default: string;
        };
        dayHeight: {
            type: (StringConstructor | NumberConstructor)[];
            default: number;
            validator: (v: any) => boolean;
        };
        dayMinHeight: {
            type: (StringConstructor | NumberConstructor)[];
            default: number;
            validator: (v: any) => boolean;
        };
        dayStyle: FunctionConstructor;
        dayClass: FunctionConstructor;
        weekdayStyle: FunctionConstructor;
        weekdayClass: FunctionConstructor;
        dayPadding: StringConstructor;
        minWeeks: {
            type: (StringConstructor | NumberConstructor)[];
            default: number;
            validator: (v: any) => boolean;
        };
        shortMonthLabel: BooleanConstructor;
        showWorkWeeks: BooleanConstructor;
        showMonthLabel: {
            type: BooleanConstructor;
            default: boolean;
        };
        showDayOfYearLabel: BooleanConstructor;
        enableOutsideDays: BooleanConstructor;
        noOutsideDays: BooleanConstructor;
        hover: BooleanConstructor;
        miniMode: {
            type: (StringConstructor | BooleanConstructor)[];
            validator: (v: any) => boolean;
        };
        breakpoint: {
            type: (StringConstructor | NumberConstructor)[];
            default: string;
            validator: (v: any) => boolean;
        };
        monthLabelSize: {
            type: StringConstructor;
            default: string;
            validator: (v: any) => boolean;
        };
        modelValue: {
            type: StringConstructor;
            default: string;
            validator: (v: string) => boolean;
        };
        weekdays: {
            type: () => number[];
            default: () => number[];
        };
        dateType: {
            type: () => "round" | "rounded" | "square";
            default: string;
            validator: (v: string) => boolean;
        };
        weekdayAlign: {
            type: () => "left" | "center" | "right";
            default: string;
            validator: (v: string) => boolean;
        };
        dateAlign: {
            type: () => "left" | "center" | "right";
            default: string;
            validator: (v: string) => boolean;
        };
        bordered: BooleanConstructor;
        dark: BooleanConstructor;
        noAria: BooleanConstructor;
        noActiveDate: BooleanConstructor;
        noHeader: BooleanConstructor;
        noScroll: BooleanConstructor;
        shortWeekdayLabel: BooleanConstructor;
        noDefaultHeaderText: BooleanConstructor;
        noDefaultHeaderBtn: BooleanConstructor;
        minWeekdayLabel: {
            type: import("vue").PropType<number | string>;
            default: number;
        };
        weekdayBreakpoints: {
            type: () => number[];
            default: () => number[];
            validator: (v: number[]) => boolean;
        };
        locale: {
            type: StringConstructor;
            default: string;
        };
        animated: BooleanConstructor;
        transitionPrev: {
            type: StringConstructor;
            default: string;
        };
        transitionNext: {
            type: StringConstructor;
            default: string;
        };
        disabledDays: () => string[];
        disabledBefore: StringConstructor;
        disabledAfter: StringConstructor;
        disabledWeekdays: {
            type: () => number[];
            default: () => string[] | Set<string>;
        };
        dragEnterFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dragOverFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dragLeaveFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dropFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        selectedDates: {
            type: import("vue").PropType<string[] | Set<string>>;
            default: () => string[] | Set<string>;
        };
        selectedStartEndDates: {
            type: () => string[];
            default: () => string[];
        };
        hoverable: BooleanConstructor;
        focusable: BooleanConstructor;
        focusType: {
            type: () => ("day" | "date" | "weekday" | "interval" | "time" | "resource" | "task")[];
            default: () => ("day" | "date" | "weekday" | "interval" | "time" | "resource" | "task")[];
            validator: (v: string[]) => boolean;
        };
    }>> & Readonly<{}>, {
        dark: boolean;
        focusable: boolean;
        now: string;
        modelValue: string;
        weekdays: number[];
        dateType: "square" | "round" | "rounded";
        weekdayAlign: "center" | "left" | "right";
        dateAlign: "center" | "left" | "right";
        bordered: boolean;
        noAria: boolean;
        noActiveDate: boolean;
        noHeader: boolean;
        noScroll: boolean;
        shortWeekdayLabel: boolean;
        noDefaultHeaderText: boolean;
        noDefaultHeaderBtn: boolean;
        minWeekdayLabel: string | number;
        weekdayBreakpoints: number[];
        locale: string;
        animated: boolean;
        transitionPrev: string;
        transitionNext: string;
        disabledWeekdays: number[];
        selectedDates: string[] | Set<string>;
        selectedStartEndDates: string[];
        hoverable: boolean;
        focusType: ("time" | "interval" | "day" | "weekday" | "date" | "resource" | "task")[];
        dayHeight: string | number;
        dayMinHeight: string | number;
        useNavigation: boolean;
        minWeeks: string | number;
        shortMonthLabel: boolean;
        showWorkWeeks: boolean;
        showMonthLabel: boolean;
        showDayOfYearLabel: boolean;
        enableOutsideDays: boolean;
        noOutsideDays: boolean;
        hover: boolean;
        breakpoint: string | number;
        monthLabelSize: string;
    }, {}, {}, {
        ResizeObserver: import("vue").Directive;
    }, string, import("vue").ComponentProvideOptions, true, {}, any>;
    QCalendarResource: import("vue").DefineComponent<import("vue").ExtractPropTypes<{
        useNavigation: BooleanConstructor;
        now: {
            type: StringConstructor;
            validator: (v: string) => boolean;
            default: string;
        };
        maxDays: {
            readonly type: import("vue").PropType<import("./composables/useMaxDays").MaxDaysProps["maxDays"]>;
            readonly default: 1;
        };
        columnCount: {
            readonly type: import("vue").PropType<import("./composables/useColumn").ColumnProps["columnCount"]>;
            readonly default: 0;
            readonly validator: typeof Timestamp.validateNumber;
        };
        columnIndexStart: {
            readonly type: import("vue").PropType<import("./composables/useColumn").ColumnProps["columnIndexStart"]>;
            readonly default: 0;
            readonly validator: typeof Timestamp.validateNumber;
        };
        view: {
            readonly type: import("vue").PropType<import("./composables/useInterval").IntervalProps["view"]>;
            readonly validator: (v: string) => boolean;
            readonly default: "day";
        };
        shortIntervalLabel: BooleanConstructor;
        intervalHeight: {
            readonly type: import("vue").PropType<import("./composables/useInterval").IntervalProps["intervalHeight"]>;
            readonly default: 40;
            readonly validator: typeof Timestamp.validateNumber;
        };
        intervalMinutes: {
            readonly type: import("vue").PropType<import("./composables/useInterval").IntervalProps["intervalMinutes"]>;
            readonly default: 60;
            readonly validator: typeof Timestamp.validateNumber;
        };
        intervalStart: {
            readonly type: import("vue").PropType<import("./composables/useInterval").IntervalProps["intervalStart"]>;
            readonly default: 0;
            readonly validator: typeof Timestamp.validateNumber;
        };
        intervalCount: {
            readonly type: import("vue").PropType<import("./composables/useInterval").IntervalProps["intervalCount"]>;
            readonly default: 24;
            readonly validator: typeof Timestamp.validateNumber;
        };
        intervalStyle: {
            readonly type: import("vue").PropType<import("./composables/useInterval").IntervalProps["intervalStyle"]>;
            readonly default: null;
        };
        intervalClass: {
            readonly type: import("vue").PropType<import("./composables/useInterval").IntervalProps["intervalClass"]>;
            readonly default: null;
        };
        weekdayStyle: {
            readonly type: import("vue").PropType<import("./composables/useInterval").IntervalProps["weekdayStyle"]>;
            readonly default: null;
        };
        weekdayClass: {
            readonly type: import("vue").PropType<import("./composables/useInterval").IntervalProps["weekdayClass"]>;
            readonly default: null;
        };
        showIntervalLabel: {
            readonly type: import("vue").PropType<import("./composables/useInterval").IntervalProps["showIntervalLabel"]>;
            readonly default: null;
        };
        hour24Format: BooleanConstructor;
        timeClicksClamped: BooleanConstructor;
        dateHeader: {
            readonly type: import("vue").PropType<import("./composables/useInterval").IntervalProps["dateHeader"]>;
            readonly default: "stacked";
            readonly validator: (v: string) => boolean;
        };
        modelResources: {
            readonly type: import("vue").PropType<import("./composables/useInterval").ResourceProps["modelResources"]>;
        };
        resourceKey: {
            readonly type: import("vue").PropType<import("./composables/useInterval").ResourceProps["resourceKey"]>;
            readonly default: "id";
        };
        resourceLabel: {
            readonly type: import("vue").PropType<import("./composables/useInterval").ResourceProps["resourceLabel"]>;
            readonly default: "label";
        };
        resourceHeight: {
            readonly type: import("vue").PropType<import("./composables/useInterval").ResourceProps["resourceHeight"]>;
            readonly default: 0;
            readonly validator: typeof Timestamp.validateNumber;
        };
        resourceMinHeight: {
            readonly type: import("vue").PropType<import("./composables/useInterval").ResourceProps["resourceMinHeight"]>;
            readonly default: 70;
            readonly validator: typeof Timestamp.validateNumber;
        };
        resourceStyle: {
            readonly type: import("vue").PropType<import("./composables/useInterval").ResourceProps["resourceStyle"]>;
            readonly default: null;
        };
        resourceClass: {
            readonly type: import("vue").PropType<import("./composables/useInterval").ResourceProps["resourceClass"]>;
            readonly default: null;
        };
        cellWidth: {
            readonly type: import("vue").PropType<import("./composables/useInterval").ResourceProps["cellWidth"]>;
            readonly default: 100;
        };
        intervalHeaderHeight: {
            readonly type: import("vue").PropType<import("./composables/useInterval").ResourceProps["intervalHeaderHeight"]>;
            readonly default: 20;
            readonly validator: typeof Timestamp.validateNumber;
        };
        noSticky: import("vue").PropType<import("./composables/useInterval").ResourceProps["noSticky"]>;
        modelValue: {
            type: StringConstructor;
            default: string;
            validator: (v: string) => boolean;
        };
        weekdays: {
            type: () => number[];
            default: () => number[];
        };
        dateType: {
            type: () => "round" | "rounded" | "square";
            default: string;
            validator: (v: string) => boolean;
        };
        weekdayAlign: {
            type: () => "left" | "center" | "right";
            default: string;
            validator: (v: string) => boolean;
        };
        dateAlign: {
            type: () => "left" | "center" | "right";
            default: string;
            validator: (v: string) => boolean;
        };
        bordered: BooleanConstructor;
        dark: BooleanConstructor;
        noAria: BooleanConstructor;
        noActiveDate: BooleanConstructor;
        noHeader: BooleanConstructor;
        noScroll: BooleanConstructor;
        shortWeekdayLabel: BooleanConstructor;
        noDefaultHeaderText: BooleanConstructor;
        noDefaultHeaderBtn: BooleanConstructor;
        minWeekdayLabel: {
            type: import("vue").PropType<number | string>;
            default: number;
        };
        weekdayBreakpoints: {
            type: () => number[];
            default: () => number[];
            validator: (v: number[]) => boolean;
        };
        locale: {
            type: StringConstructor;
            default: string;
        };
        animated: BooleanConstructor;
        transitionPrev: {
            type: StringConstructor;
            default: string;
        };
        transitionNext: {
            type: StringConstructor;
            default: string;
        };
        disabledDays: () => string[];
        disabledBefore: StringConstructor;
        disabledAfter: StringConstructor;
        disabledWeekdays: {
            type: () => number[];
            default: () => string[] | Set<string>;
        };
        dragEnterFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dragOverFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dragLeaveFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dropFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        selectedDates: {
            type: import("vue").PropType<string[] | Set<string>>;
            default: () => string[] | Set<string>;
        };
        selectedStartEndDates: {
            type: () => string[];
            default: () => string[];
        };
        hoverable: BooleanConstructor;
        focusable: BooleanConstructor;
        focusType: {
            type: () => ("day" | "date" | "weekday" | "interval" | "time" | "resource" | "task")[];
            default: () => ("day" | "date" | "weekday" | "interval" | "time" | "resource" | "task")[];
            validator: (v: string[]) => boolean;
        };
    }>, () => import("vue").VNode, {}, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
        useNavigation: BooleanConstructor;
        now: {
            type: StringConstructor;
            validator: (v: string) => boolean;
            default: string;
        };
        maxDays: {
            readonly type: import("vue").PropType<import("./composables/useMaxDays").MaxDaysProps["maxDays"]>;
            readonly default: 1;
        };
        columnCount: {
            readonly type: import("vue").PropType<import("./composables/useColumn").ColumnProps["columnCount"]>;
            readonly default: 0;
            readonly validator: typeof Timestamp.validateNumber;
        };
        columnIndexStart: {
            readonly type: import("vue").PropType<import("./composables/useColumn").ColumnProps["columnIndexStart"]>;
            readonly default: 0;
            readonly validator: typeof Timestamp.validateNumber;
        };
        view: {
            readonly type: import("vue").PropType<import("./composables/useInterval").IntervalProps["view"]>;
            readonly validator: (v: string) => boolean;
            readonly default: "day";
        };
        shortIntervalLabel: BooleanConstructor;
        intervalHeight: {
            readonly type: import("vue").PropType<import("./composables/useInterval").IntervalProps["intervalHeight"]>;
            readonly default: 40;
            readonly validator: typeof Timestamp.validateNumber;
        };
        intervalMinutes: {
            readonly type: import("vue").PropType<import("./composables/useInterval").IntervalProps["intervalMinutes"]>;
            readonly default: 60;
            readonly validator: typeof Timestamp.validateNumber;
        };
        intervalStart: {
            readonly type: import("vue").PropType<import("./composables/useInterval").IntervalProps["intervalStart"]>;
            readonly default: 0;
            readonly validator: typeof Timestamp.validateNumber;
        };
        intervalCount: {
            readonly type: import("vue").PropType<import("./composables/useInterval").IntervalProps["intervalCount"]>;
            readonly default: 24;
            readonly validator: typeof Timestamp.validateNumber;
        };
        intervalStyle: {
            readonly type: import("vue").PropType<import("./composables/useInterval").IntervalProps["intervalStyle"]>;
            readonly default: null;
        };
        intervalClass: {
            readonly type: import("vue").PropType<import("./composables/useInterval").IntervalProps["intervalClass"]>;
            readonly default: null;
        };
        weekdayStyle: {
            readonly type: import("vue").PropType<import("./composables/useInterval").IntervalProps["weekdayStyle"]>;
            readonly default: null;
        };
        weekdayClass: {
            readonly type: import("vue").PropType<import("./composables/useInterval").IntervalProps["weekdayClass"]>;
            readonly default: null;
        };
        showIntervalLabel: {
            readonly type: import("vue").PropType<import("./composables/useInterval").IntervalProps["showIntervalLabel"]>;
            readonly default: null;
        };
        hour24Format: BooleanConstructor;
        timeClicksClamped: BooleanConstructor;
        dateHeader: {
            readonly type: import("vue").PropType<import("./composables/useInterval").IntervalProps["dateHeader"]>;
            readonly default: "stacked";
            readonly validator: (v: string) => boolean;
        };
        modelResources: {
            readonly type: import("vue").PropType<import("./composables/useInterval").ResourceProps["modelResources"]>;
        };
        resourceKey: {
            readonly type: import("vue").PropType<import("./composables/useInterval").ResourceProps["resourceKey"]>;
            readonly default: "id";
        };
        resourceLabel: {
            readonly type: import("vue").PropType<import("./composables/useInterval").ResourceProps["resourceLabel"]>;
            readonly default: "label";
        };
        resourceHeight: {
            readonly type: import("vue").PropType<import("./composables/useInterval").ResourceProps["resourceHeight"]>;
            readonly default: 0;
            readonly validator: typeof Timestamp.validateNumber;
        };
        resourceMinHeight: {
            readonly type: import("vue").PropType<import("./composables/useInterval").ResourceProps["resourceMinHeight"]>;
            readonly default: 70;
            readonly validator: typeof Timestamp.validateNumber;
        };
        resourceStyle: {
            readonly type: import("vue").PropType<import("./composables/useInterval").ResourceProps["resourceStyle"]>;
            readonly default: null;
        };
        resourceClass: {
            readonly type: import("vue").PropType<import("./composables/useInterval").ResourceProps["resourceClass"]>;
            readonly default: null;
        };
        cellWidth: {
            readonly type: import("vue").PropType<import("./composables/useInterval").ResourceProps["cellWidth"]>;
            readonly default: 100;
        };
        intervalHeaderHeight: {
            readonly type: import("vue").PropType<import("./composables/useInterval").ResourceProps["intervalHeaderHeight"]>;
            readonly default: 20;
            readonly validator: typeof Timestamp.validateNumber;
        };
        noSticky: import("vue").PropType<import("./composables/useInterval").ResourceProps["noSticky"]>;
        modelValue: {
            type: StringConstructor;
            default: string;
            validator: (v: string) => boolean;
        };
        weekdays: {
            type: () => number[];
            default: () => number[];
        };
        dateType: {
            type: () => "round" | "rounded" | "square";
            default: string;
            validator: (v: string) => boolean;
        };
        weekdayAlign: {
            type: () => "left" | "center" | "right";
            default: string;
            validator: (v: string) => boolean;
        };
        dateAlign: {
            type: () => "left" | "center" | "right";
            default: string;
            validator: (v: string) => boolean;
        };
        bordered: BooleanConstructor;
        dark: BooleanConstructor;
        noAria: BooleanConstructor;
        noActiveDate: BooleanConstructor;
        noHeader: BooleanConstructor;
        noScroll: BooleanConstructor;
        shortWeekdayLabel: BooleanConstructor;
        noDefaultHeaderText: BooleanConstructor;
        noDefaultHeaderBtn: BooleanConstructor;
        minWeekdayLabel: {
            type: import("vue").PropType<number | string>;
            default: number;
        };
        weekdayBreakpoints: {
            type: () => number[];
            default: () => number[];
            validator: (v: number[]) => boolean;
        };
        locale: {
            type: StringConstructor;
            default: string;
        };
        animated: BooleanConstructor;
        transitionPrev: {
            type: StringConstructor;
            default: string;
        };
        transitionNext: {
            type: StringConstructor;
            default: string;
        };
        disabledDays: () => string[];
        disabledBefore: StringConstructor;
        disabledAfter: StringConstructor;
        disabledWeekdays: {
            type: () => number[];
            default: () => string[] | Set<string>;
        };
        dragEnterFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dragOverFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dragLeaveFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dropFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        selectedDates: {
            type: import("vue").PropType<string[] | Set<string>>;
            default: () => string[] | Set<string>;
        };
        selectedStartEndDates: {
            type: () => string[];
            default: () => string[];
        };
        hoverable: BooleanConstructor;
        focusable: BooleanConstructor;
        focusType: {
            type: () => ("day" | "date" | "weekday" | "interval" | "time" | "resource" | "task")[];
            default: () => ("day" | "date" | "weekday" | "interval" | "time" | "resource" | "task")[];
            validator: (v: string[]) => boolean;
        };
    }>> & Readonly<{}>, {
        view: "day" | "month" | "week" | "month-interval";
        columnCount: string | number;
        dark: boolean;
        focusable: boolean;
        columnIndexStart: string | number;
        now: string;
        maxDays: number;
        shortIntervalLabel: boolean;
        intervalHeight: string | number;
        intervalMinutes: string | number;
        intervalStart: string | number;
        intervalCount: string | number;
        intervalStyle: ((_scope: import("./composables/useInterval").Scope) => any) | undefined;
        intervalClass: ((_scope: import("./composables/useInterval").Scope) => string) | undefined;
        weekdayStyle: ((_scope: import("./composables/useInterval").Scope) => any) | undefined;
        weekdayClass: ((_scope: import("./composables/useInterval").Scope) => string) | undefined;
        showIntervalLabel: ((_timestamp: Timestamp.Timestamp) => any) | undefined;
        hour24Format: boolean;
        timeClicksClamped: boolean;
        dateHeader: "inline" | "stacked" | "inverted";
        modelValue: string;
        weekdays: number[];
        dateType: "square" | "round" | "rounded";
        weekdayAlign: "center" | "left" | "right";
        dateAlign: "center" | "left" | "right";
        bordered: boolean;
        noAria: boolean;
        noActiveDate: boolean;
        noHeader: boolean;
        noScroll: boolean;
        shortWeekdayLabel: boolean;
        noDefaultHeaderText: boolean;
        noDefaultHeaderBtn: boolean;
        minWeekdayLabel: string | number;
        weekdayBreakpoints: number[];
        locale: string;
        animated: boolean;
        transitionPrev: string;
        transitionNext: string;
        disabledWeekdays: number[];
        selectedDates: string[] | Set<string>;
        selectedStartEndDates: string[];
        hoverable: boolean;
        focusType: ("time" | "interval" | "day" | "weekday" | "date" | "resource" | "task")[];
        resourceKey: string;
        resourceLabel: string;
        resourceHeight: string | number;
        resourceMinHeight: string | number;
        resourceStyle: ((_scope: any) => any) | undefined;
        resourceClass: ((_scope: any) => string) | undefined;
        cellWidth: string | number;
        intervalHeaderHeight: string | number;
        useNavigation: boolean;
    }, {}, {}, {}, string, import("vue").ComponentProvideOptions, true, {}, any>;
    QCalendarScheduler: import("vue").DefineComponent<import("vue").ExtractPropTypes<{
        useNavigation: BooleanConstructor;
        cellWidth: (StringConstructor | NumberConstructor)[];
        now: {
            type: StringConstructor;
            validator: (v: string) => boolean;
            default: string;
        };
        maxDays: {
            readonly type: import("vue").PropType<import("./composables/useMaxDays").MaxDaysProps["maxDays"]>;
            readonly default: 1;
        };
        columnCount: {
            readonly type: import("vue").PropType<import("./composables/useColumn").ColumnProps["columnCount"]>;
            readonly default: 0;
            readonly validator: typeof Timestamp.validateNumber;
        };
        columnIndexStart: {
            readonly type: import("vue").PropType<import("./composables/useColumn").ColumnProps["columnIndexStart"]>;
            readonly default: 0;
            readonly validator: typeof Timestamp.validateNumber;
        };
        view: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["view"]>;
            readonly validator: (v: string) => boolean;
            readonly default: "day";
        };
        modelResources: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["modelResources"]>;
        };
        resourceKey: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["resourceKey"]>;
            readonly default: "id";
        };
        resourceLabel: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["resourceLabel"]>;
            readonly default: "label";
        };
        resourceHeight: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["resourceHeight"]>;
            readonly default: 0;
            readonly validator: typeof Timestamp.validateNumber;
        };
        resourceMinHeight: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["resourceMinHeight"]>;
            readonly default: 70;
            readonly validator: typeof Timestamp.validateNumber;
        };
        resourceStyle: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["resourceStyle"]>;
            readonly default: null;
        };
        resourceClass: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["resourceClass"]>;
            readonly default: null;
        };
        weekdayStyle: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["weekdayStyle"]>;
            readonly default: null;
        };
        weekdayClass: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["weekdayClass"]>;
            readonly default: null;
        };
        dayStyle: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["dayStyle"]>;
            readonly default: null;
        };
        dayClass: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["dayClass"]>;
            readonly default: null;
        };
        dateHeader: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["dateHeader"]>;
            readonly default: "stacked";
            readonly validator: (v: string) => boolean;
        };
        modelValue: {
            type: StringConstructor;
            default: string;
            validator: (v: string) => boolean;
        };
        weekdays: {
            type: () => number[];
            default: () => number[];
        };
        dateType: {
            type: () => "round" | "rounded" | "square";
            default: string;
            validator: (v: string) => boolean;
        };
        weekdayAlign: {
            type: () => "left" | "center" | "right";
            default: string;
            validator: (v: string) => boolean;
        };
        dateAlign: {
            type: () => "left" | "center" | "right";
            default: string;
            validator: (v: string) => boolean;
        };
        bordered: BooleanConstructor;
        dark: BooleanConstructor;
        noAria: BooleanConstructor;
        noActiveDate: BooleanConstructor;
        noHeader: BooleanConstructor;
        noScroll: BooleanConstructor;
        shortWeekdayLabel: BooleanConstructor;
        noDefaultHeaderText: BooleanConstructor;
        noDefaultHeaderBtn: BooleanConstructor;
        minWeekdayLabel: {
            type: import("vue").PropType<number | string>;
            default: number;
        };
        weekdayBreakpoints: {
            type: () => number[];
            default: () => number[];
            validator: (v: number[]) => boolean;
        };
        locale: {
            type: StringConstructor;
            default: string;
        };
        animated: BooleanConstructor;
        transitionPrev: {
            type: StringConstructor;
            default: string;
        };
        transitionNext: {
            type: StringConstructor;
            default: string;
        };
        disabledDays: () => string[];
        disabledBefore: StringConstructor;
        disabledAfter: StringConstructor;
        disabledWeekdays: {
            type: () => number[];
            default: () => string[] | Set<string>;
        };
        dragEnterFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dragOverFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dragLeaveFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dropFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        selectedDates: {
            type: import("vue").PropType<string[] | Set<string>>;
            default: () => string[] | Set<string>;
        };
        selectedStartEndDates: {
            type: () => string[];
            default: () => string[];
        };
        hoverable: BooleanConstructor;
        focusable: BooleanConstructor;
        focusType: {
            type: () => ("day" | "date" | "weekday" | "interval" | "time" | "resource" | "task")[];
            default: () => ("day" | "date" | "weekday" | "interval" | "time" | "resource" | "task")[];
            validator: (v: string[]) => boolean;
        };
    }>, () => import("vue").VNode, {}, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
        useNavigation: BooleanConstructor;
        cellWidth: (StringConstructor | NumberConstructor)[];
        now: {
            type: StringConstructor;
            validator: (v: string) => boolean;
            default: string;
        };
        maxDays: {
            readonly type: import("vue").PropType<import("./composables/useMaxDays").MaxDaysProps["maxDays"]>;
            readonly default: 1;
        };
        columnCount: {
            readonly type: import("vue").PropType<import("./composables/useColumn").ColumnProps["columnCount"]>;
            readonly default: 0;
            readonly validator: typeof Timestamp.validateNumber;
        };
        columnIndexStart: {
            readonly type: import("vue").PropType<import("./composables/useColumn").ColumnProps["columnIndexStart"]>;
            readonly default: 0;
            readonly validator: typeof Timestamp.validateNumber;
        };
        view: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["view"]>;
            readonly validator: (v: string) => boolean;
            readonly default: "day";
        };
        modelResources: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["modelResources"]>;
        };
        resourceKey: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["resourceKey"]>;
            readonly default: "id";
        };
        resourceLabel: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["resourceLabel"]>;
            readonly default: "label";
        };
        resourceHeight: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["resourceHeight"]>;
            readonly default: 0;
            readonly validator: typeof Timestamp.validateNumber;
        };
        resourceMinHeight: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["resourceMinHeight"]>;
            readonly default: 70;
            readonly validator: typeof Timestamp.validateNumber;
        };
        resourceStyle: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["resourceStyle"]>;
            readonly default: null;
        };
        resourceClass: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["resourceClass"]>;
            readonly default: null;
        };
        weekdayStyle: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["weekdayStyle"]>;
            readonly default: null;
        };
        weekdayClass: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["weekdayClass"]>;
            readonly default: null;
        };
        dayStyle: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["dayStyle"]>;
            readonly default: null;
        };
        dayClass: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["dayClass"]>;
            readonly default: null;
        };
        dateHeader: {
            readonly type: import("vue").PropType<import("./composables/useInterval").SchedulerProps["dateHeader"]>;
            readonly default: "stacked";
            readonly validator: (v: string) => boolean;
        };
        modelValue: {
            type: StringConstructor;
            default: string;
            validator: (v: string) => boolean;
        };
        weekdays: {
            type: () => number[];
            default: () => number[];
        };
        dateType: {
            type: () => "round" | "rounded" | "square";
            default: string;
            validator: (v: string) => boolean;
        };
        weekdayAlign: {
            type: () => "left" | "center" | "right";
            default: string;
            validator: (v: string) => boolean;
        };
        dateAlign: {
            type: () => "left" | "center" | "right";
            default: string;
            validator: (v: string) => boolean;
        };
        bordered: BooleanConstructor;
        dark: BooleanConstructor;
        noAria: BooleanConstructor;
        noActiveDate: BooleanConstructor;
        noHeader: BooleanConstructor;
        noScroll: BooleanConstructor;
        shortWeekdayLabel: BooleanConstructor;
        noDefaultHeaderText: BooleanConstructor;
        noDefaultHeaderBtn: BooleanConstructor;
        minWeekdayLabel: {
            type: import("vue").PropType<number | string>;
            default: number;
        };
        weekdayBreakpoints: {
            type: () => number[];
            default: () => number[];
            validator: (v: number[]) => boolean;
        };
        locale: {
            type: StringConstructor;
            default: string;
        };
        animated: BooleanConstructor;
        transitionPrev: {
            type: StringConstructor;
            default: string;
        };
        transitionNext: {
            type: StringConstructor;
            default: string;
        };
        disabledDays: () => string[];
        disabledBefore: StringConstructor;
        disabledAfter: StringConstructor;
        disabledWeekdays: {
            type: () => number[];
            default: () => string[] | Set<string>;
        };
        dragEnterFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dragOverFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dragLeaveFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dropFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        selectedDates: {
            type: import("vue").PropType<string[] | Set<string>>;
            default: () => string[] | Set<string>;
        };
        selectedStartEndDates: {
            type: () => string[];
            default: () => string[];
        };
        hoverable: BooleanConstructor;
        focusable: BooleanConstructor;
        focusType: {
            type: () => ("day" | "date" | "weekday" | "interval" | "time" | "resource" | "task")[];
            default: () => ("day" | "date" | "weekday" | "interval" | "time" | "resource" | "task")[];
            validator: (v: string[]) => boolean;
        };
    }>> & Readonly<{}>, {
        view: "day" | "month" | "week" | "month-interval";
        columnCount: string | number;
        dark: boolean;
        focusable: boolean;
        columnIndexStart: string | number;
        now: string;
        maxDays: number;
        weekdayStyle: ((_scope: import("./composables/useInterval").Scope) => any) | undefined;
        weekdayClass: ((_scope: import("./composables/useInterval").Scope) => string) | undefined;
        dateHeader: "inline" | "stacked" | "inverted";
        modelValue: string;
        weekdays: number[];
        dateType: "square" | "round" | "rounded";
        weekdayAlign: "center" | "left" | "right";
        dateAlign: "center" | "left" | "right";
        bordered: boolean;
        noAria: boolean;
        noActiveDate: boolean;
        noHeader: boolean;
        noScroll: boolean;
        shortWeekdayLabel: boolean;
        noDefaultHeaderText: boolean;
        noDefaultHeaderBtn: boolean;
        minWeekdayLabel: string | number;
        weekdayBreakpoints: number[];
        locale: string;
        animated: boolean;
        transitionPrev: string;
        transitionNext: string;
        disabledWeekdays: number[];
        selectedDates: string[] | Set<string>;
        selectedStartEndDates: string[];
        hoverable: boolean;
        focusType: ("time" | "interval" | "day" | "weekday" | "date" | "resource" | "task")[];
        resourceKey: string;
        resourceLabel: string;
        resourceHeight: string | number;
        resourceMinHeight: string | number;
        resourceStyle: ((_timestamp: Timestamp.Timestamp) => any) | undefined;
        resourceClass: ((_scope: import("./composables/useInterval").Scope) => string) | undefined;
        dayStyle: ((_scope: import("./composables/useInterval").Scope) => any) | undefined;
        dayClass: ((_scope: import("./composables/useInterval").Scope) => string) | undefined;
        useNavigation: boolean;
    }, {}, {}, {
        ResizeObserver: import("vue").Directive;
    }, string, import("vue").ComponentProvideOptions, true, {}, any>;
    QCalendarTask: import("vue").DefineComponent<import("vue").ExtractPropTypes<{
        modelValue: {
            type: StringConstructor;
            default: string;
            validator: (v: string) => boolean;
        };
        modelTasks: {
            type: () => Array<any>;
            default: () => any[];
        };
        modelTitle: {
            type: () => Array<any>;
            default: () => any[];
        };
        modelFooter: {
            type: () => Array<any>;
            default: () => any[];
        };
        taskKey: {
            type: import("vue").PropType<string | number>;
            default: string;
        };
        weekdays: {
            type: () => number[];
            default: () => number[];
        };
        dateType: {
            type: () => "round" | "rounded" | "square";
            default: string;
            validator: (v: string) => boolean;
        };
        dateHeader: {
            type: () => "stacked" | "inline" | "inverted";
            default: string;
            validator: (v: string) => boolean;
        };
        weekdayAlign: {
            type: () => "left" | "center" | "right";
            default: string;
            validator: (v: string) => boolean;
        };
        dateAlign: {
            type: () => "left" | "center" | "right";
            default: string;
            validator: (v: string) => boolean;
        };
        dayHeight: {
            type: (StringConstructor | NumberConstructor)[];
            default: number;
            validator: typeof Timestamp.validateNumber;
        };
        dayMinHeight: {
            type: (StringConstructor | NumberConstructor)[];
            default: number;
            validator: typeof Timestamp.validateNumber;
        };
        weekdayStyle: {
            type: FunctionConstructor;
            default: null;
        };
        weekdayClass: {
            type: FunctionConstructor;
            default: null;
        };
        dayStyle: {
            type: FunctionConstructor;
            default: null;
        };
        dayClass: {
            type: FunctionConstructor;
            default: null;
        };
        footerDayClass: {
            type: FunctionConstructor;
            default: null;
        };
        view: {
            type: () => "day" | "week" | "month";
            validator: (v: string) => boolean;
        };
        viewCount: {
            type: NumberConstructor;
            default: number;
            validator: (v: number) => boolean;
        };
        taskWidth: {
            type: NumberConstructor;
            default: number;
            validator: (v: number) => boolean;
        };
        bordered: BooleanConstructor;
        dark: BooleanConstructor;
        noAria: BooleanConstructor;
        noActiveDate: BooleanConstructor;
        noHeader: BooleanConstructor;
        noScroll: BooleanConstructor;
        shortWeekdayLabel: BooleanConstructor;
        noDefaultHeaderText: BooleanConstructor;
        noDefaultHeaderBtn: BooleanConstructor;
        minWeekdayLabel: {
            type: import("vue").PropType<number | string>;
            default: number;
        };
        weekdayBreakpoints: {
            type: () => number[];
            default: () => number[];
            validator: (v: number[]) => boolean;
        };
        locale: {
            type: StringConstructor;
            default: string;
        };
        animated: BooleanConstructor;
        transitionPrev: {
            type: StringConstructor;
            default: string;
        };
        transitionNext: {
            type: StringConstructor;
            default: string;
        };
        disabledDays: () => string[];
        disabledBefore: StringConstructor;
        disabledAfter: StringConstructor;
        disabledWeekdays: {
            type: () => number[];
            default: () => string[] | Set<string>;
        };
        dragEnterFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dragOverFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dragLeaveFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dropFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        selectedDates: {
            type: import("vue").PropType<string[] | Set<string>>;
            default: () => string[] | Set<string>;
        };
        selectedStartEndDates: {
            type: () => string[];
            default: () => string[];
        };
        hoverable: BooleanConstructor;
        focusable: BooleanConstructor;
        focusType: {
            type: () => ("day" | "date" | "weekday" | "interval" | "time" | "resource" | "task")[];
            default: () => ("day" | "date" | "weekday" | "interval" | "time" | "resource" | "task")[];
            validator: (v: string[]) => boolean;
        };
        cellWidth: (StringConstructor | NumberConstructor)[];
        useNavigation: BooleanConstructor;
        now: {
            type: StringConstructor;
            validator: (v: string) => boolean;
            default: string;
        };
    }>, () => import("vue").VNode, {}, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
        modelValue: {
            type: StringConstructor;
            default: string;
            validator: (v: string) => boolean;
        };
        modelTasks: {
            type: () => Array<any>;
            default: () => any[];
        };
        modelTitle: {
            type: () => Array<any>;
            default: () => any[];
        };
        modelFooter: {
            type: () => Array<any>;
            default: () => any[];
        };
        taskKey: {
            type: import("vue").PropType<string | number>;
            default: string;
        };
        weekdays: {
            type: () => number[];
            default: () => number[];
        };
        dateType: {
            type: () => "round" | "rounded" | "square";
            default: string;
            validator: (v: string) => boolean;
        };
        dateHeader: {
            type: () => "stacked" | "inline" | "inverted";
            default: string;
            validator: (v: string) => boolean;
        };
        weekdayAlign: {
            type: () => "left" | "center" | "right";
            default: string;
            validator: (v: string) => boolean;
        };
        dateAlign: {
            type: () => "left" | "center" | "right";
            default: string;
            validator: (v: string) => boolean;
        };
        dayHeight: {
            type: (StringConstructor | NumberConstructor)[];
            default: number;
            validator: typeof Timestamp.validateNumber;
        };
        dayMinHeight: {
            type: (StringConstructor | NumberConstructor)[];
            default: number;
            validator: typeof Timestamp.validateNumber;
        };
        weekdayStyle: {
            type: FunctionConstructor;
            default: null;
        };
        weekdayClass: {
            type: FunctionConstructor;
            default: null;
        };
        dayStyle: {
            type: FunctionConstructor;
            default: null;
        };
        dayClass: {
            type: FunctionConstructor;
            default: null;
        };
        footerDayClass: {
            type: FunctionConstructor;
            default: null;
        };
        view: {
            type: () => "day" | "week" | "month";
            validator: (v: string) => boolean;
        };
        viewCount: {
            type: NumberConstructor;
            default: number;
            validator: (v: number) => boolean;
        };
        taskWidth: {
            type: NumberConstructor;
            default: number;
            validator: (v: number) => boolean;
        };
        bordered: BooleanConstructor;
        dark: BooleanConstructor;
        noAria: BooleanConstructor;
        noActiveDate: BooleanConstructor;
        noHeader: BooleanConstructor;
        noScroll: BooleanConstructor;
        shortWeekdayLabel: BooleanConstructor;
        noDefaultHeaderText: BooleanConstructor;
        noDefaultHeaderBtn: BooleanConstructor;
        minWeekdayLabel: {
            type: import("vue").PropType<number | string>;
            default: number;
        };
        weekdayBreakpoints: {
            type: () => number[];
            default: () => number[];
            validator: (v: number[]) => boolean;
        };
        locale: {
            type: StringConstructor;
            default: string;
        };
        animated: BooleanConstructor;
        transitionPrev: {
            type: StringConstructor;
            default: string;
        };
        transitionNext: {
            type: StringConstructor;
            default: string;
        };
        disabledDays: () => string[];
        disabledBefore: StringConstructor;
        disabledAfter: StringConstructor;
        disabledWeekdays: {
            type: () => number[];
            default: () => string[] | Set<string>;
        };
        dragEnterFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dragOverFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dragLeaveFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        dropFunc: import("vue").PropType<(_event: Event, _type: string, _scope: any) => boolean>;
        selectedDates: {
            type: import("vue").PropType<string[] | Set<string>>;
            default: () => string[] | Set<string>;
        };
        selectedStartEndDates: {
            type: () => string[];
            default: () => string[];
        };
        hoverable: BooleanConstructor;
        focusable: BooleanConstructor;
        focusType: {
            type: () => ("day" | "date" | "weekday" | "interval" | "time" | "resource" | "task")[];
            default: () => ("day" | "date" | "weekday" | "interval" | "time" | "resource" | "task")[];
            validator: (v: string[]) => boolean;
        };
        cellWidth: (StringConstructor | NumberConstructor)[];
        useNavigation: BooleanConstructor;
        now: {
            type: StringConstructor;
            validator: (v: string) => boolean;
            default: string;
        };
    }>> & Readonly<{}>, {
        dark: boolean;
        focusable: boolean;
        now: string;
        weekdayStyle: Function;
        weekdayClass: Function;
        dateHeader: "inline" | "stacked" | "inverted";
        modelValue: string;
        weekdays: number[];
        dateType: "square" | "round" | "rounded";
        weekdayAlign: "center" | "left" | "right";
        dateAlign: "center" | "left" | "right";
        bordered: boolean;
        noAria: boolean;
        noActiveDate: boolean;
        noHeader: boolean;
        noScroll: boolean;
        shortWeekdayLabel: boolean;
        noDefaultHeaderText: boolean;
        noDefaultHeaderBtn: boolean;
        minWeekdayLabel: string | number;
        weekdayBreakpoints: number[];
        locale: string;
        animated: boolean;
        transitionPrev: string;
        transitionNext: string;
        disabledWeekdays: number[];
        selectedDates: string[] | Set<string>;
        selectedStartEndDates: string[];
        hoverable: boolean;
        focusType: ("time" | "interval" | "day" | "weekday" | "date" | "resource" | "task")[];
        dayStyle: Function;
        dayClass: Function;
        dayHeight: string | number;
        dayMinHeight: string | number;
        useNavigation: boolean;
        modelTasks: any[];
        modelTitle: any[];
        modelFooter: any[];
        taskKey: string | number;
        footerDayClass: Function;
        viewCount: number;
        taskWidth: number;
    }, {}, {}, {
        ResizeObserver: import("vue").Directive;
    }, string, import("vue").ComponentProvideOptions, true, {}, any>;
};
export default _default;
